OC.L10N.register(
    "lib",
    {
    "Unknown filetype" : "Nepoznat tip fajla",
    "Invalid image" : "Neispravna slika",
    "today" : "Danas",
    "yesterday" : "juče",
    "last month" : "prošlog meseca",
    "last year" : "prošle godine",
    "seconds ago" : "Pre par sekundi",
    "Username" : "Korisničko ime",
    "Password" : "Lozinka",
    "Apps" : "Programi",
    "General" : "Opšte",
    "Search" : "Traži",
    "Updates" : "Ažuriranja",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X nije podržan i %s neće raditi kako treba na ovoj platformi. Koristite na sopstvenu odgovornost.",
    "For the best results, please consider using a GNU/Linux server instead." : "Za najbolje rezultate uzmite u obzir korišćenje GNU/Linux servera.",
    "Help" : "Pomoć",
    "Settings" : "Podešavanja",
    "Users" : "Korisnici",
    "Authentication error" : "Greška pri autentifikaciji"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
